# Magyar nevek listái

vezeteknev = ['Kovács', 'Nagy', 'Kiss', 'Tóth', 'Varga', 'Farkas', 'Horváth', 'Szabó', 'Molnár', 'Balázs',
              'Lakatos', 'Takács', 'Papp', 'Katona', 'Szilágyi', 'Balogh', 'Gulyás', 'Szőke', 'Simon', 'Fehér',
              'Barta', 'Császár', 'Sándor', 'Fodor', 'Bakos', 'László', 'Kerekes', 'Fekete', 'Török', 'Pintér',
              'Juhász', 'Gáspár', 'Kis', 'Bognár', 'Hajdu', 'Kónya', 'Kozma', 'Borbély', 'Budai', 'Hegedűs',
              'Ács', 'Bálint', 'Rácz', 'Virág', 'Sipos', 'Kelemen', 'Gál', 'Szőllősi', 'Lengyel', 'Füredi',
              'Magyar', 'Fazekas', 'Antal', 'Bérczes', 'Temesvári', 'Oláh', 'Pál', 'Barna', 'Bajnai', 'Balog',
              'Kocsis', 'Halász', 'Kertész', 'Boros', 'Fekete', 'Bérczi', 'Vincze', 'Dudás', 'Mészáros',
              'Gombos', 'Árkosi', 'Pánczél', 'Karádi', 'Kulcsár', 'Ágoston', 'Pap', 'Pálinkás', 'Csák', 'Bódi',
              'Kerekes', 'Fischer', 'Győri', 'Magyar', 'Péter', 'Fenyő', 'Kocsis', 'Fazekas', 'Kis-Benedek',
              'Bán', 'Bánhidi', 'Kovácsik', 'Kincses', 'Iványi', 'Bertalan', 'Molnár', 'Papp', 'Benedek',
              'Huszár', 'Kis-Gál', 'Németh', 'Somogyi', 'Boda', 'Budai', 'Székely', 'Borsos', 'Czeglédi',
              'Árvai', 'Miklós', 'Füzesi', 'Pap', 'Kisfaludi', 'Pongrácz', 'Tóth', 'Budavári', 'Sajó',
              'Mészáros', 'Lévai', 'Kéri', 'Czakó', 'Csordás', 'Mészáros', 'Bodó', 'Kántor', 'Nagy-Balogh',
              'Szekeres', 'Takács', 'Jakab', 'Herczeg', 'Vajda', 'Gyuris', 'Kincs', 'Végh', 'Lukács', 'Erdélyi',
              'Simon', 'Bárdi', 'Szabó-Balog', 'Szubin']

keresztnev_n = ['Anna', 'Cecília', 'Erika', 'Hanna', 'Katalin', 'Mária', 'Nóra', 'Orsolya', 'Réka', 'Szilvia',
                'Tünde', 'Viktória', 'Dóra', 'Eszter', 'Flóra', 'Hajnalka', 'Izabella', 'Jázmin', 'Kamilla', 'Nikolett',
                'Panna', 'Rita', 'Sarolta', 'Zsófia', 'Ágota', 'Csilla', 'Lilla', 'Orsolya', 'Panna',
                'Szandra', 'Tamara', 'Ágnes', 'Júlia', 'Kincső', 'Babett', 'Barbara', 'Beáta', 'Bianka',
                'Blanka', 'Boglárka', 'Borbála', 'Boróka', 'Brigitta', 'Bernadett', 'Bettina', 'Berta', 'Betti',
                'Bianka', 'Cecília', 'Cintia', 'Csenge', 'Csilla', 'Detti', 'Diana', 'Dóra', 'Dalma', 'Daniella',
                'Debóra', 'Dolli', 'Dominika']

keresztnev_f = ['Ábel', 'Ádám', 'Ákos', 'Aladár', 'Albert', 'Albin', 'Alekszander', 'Alfréd', 'Ambrus', 'Andor',
                'András', 'Áron', 'Árpád', 'Attila', 'Aurél', 'Bálint', 'Barna', 'Barnabás', 'Béla', 'Benedek',
                'Benjámin', 'Bernát', 'Botond', 'Csongor', 'Dénes', 'Dániel', 'Dávid', 'Dezső', 'Dominik', 'Donát',
                'Edgár', 'Edmund', 'Ede', 'Eduárd', 'Endre', 'Erik', 'Ernő', 'Fábián', 'Farkas', 'Ferenc', 'Flórián',
                'Gábor', 'Géza', 'Gergely', 'Gusztáv', 'György', 'Győző', 'Hunor', 'Igor', 'Imre', 'István', 'János',
                'József', 'Kálmán', 'Károly', 'Kázmér', 'Kelemen', 'Kende', 'Kornél', 'Kristóf',
                'Lajos', 'László', 'Levente', 'Lóránt', 'Lóránd', 'Lukács', 'Márió', 'Márk', 'Márton', 'Mátyás',
                'Miklós', 'Milán', 'Mózes', 'Nándor', 'Nikolasz', 'Noé', 'Norbert', 'Olivér', 'Ödön', 'Oszkár',
                'Ottó', 'Pál', 'Patrik', 'Péter', 'Róbert', 'Rudolf', 'Sámuel', 'Sándor', 'Sebestyén', 'Soma',
                'Szabolcs', 'Szilárd', 'Szilveszter', 'Tamás', 'Tihamér', 'Tibor', 'Tivadar', 'Tódor', 'Tóbiás',
                'Vencel', 'Viktor', 'Vilmos', 'Vince', 'Zalán', 'Zétény', 'Zoltán', 'Zsigmond', 'Zsolt']

keresztnev_v =['Ábel', 'Ádám', 'Ákos', 'Aladár', 'Albert', 'Albin', 'Alekszander', 'Alfréd', 'Ambrus', 'Andor',
                'András', 'Áron', 'Árpád', 'Attila', 'Aurél', 'Bálint', 'Barna', 'Barnabás', 'Béla', 'Benedek',
                'Benjámin', 'Bernát', 'Botond', 'Csongor', 'Dénes', 'Dániel', 'Dávid', 'Dezső', 'Dominik', 'Donát',
                'Edgár', 'Edmund', 'Ede', 'Eduárd', 'Endre', 'Erik', 'Ernő', 'Fábián', 'Farkas', 'Ferenc', 'Flórián',
                'Gábor', 'Géza', 'Gergely', 'Gusztáv', 'György', 'Győző', 'Hunor', 'Igor', 'Imre', 'István', 'János',
                'József', 'Kálmán', 'Károly', 'Kázmér', 'Kelemen', 'Kende', 'Kornél', 'Kristóf',
                'Lajos', 'László', 'Levente', 'Lóránt', 'Lóránd', 'Lukács', 'Márió', 'Márk', 'Márton', 'Mátyás',
                'Miklós', 'Milán', 'Mózes', 'Nándor', 'Nikolasz', 'Noé', 'Norbert', 'Olivér', 'Ödön', 'Oszkár',
                'Ottó', 'Pál', 'Patrik', 'Péter', 'Róbert', 'Rudolf', 'Sámuel', 'Sándor', 'Sebestyén', 'Soma',
                'Szabolcs', 'Szilárd', 'Szilveszter', 'Tamás', 'Tihamér', 'Tibor', 'Tivadar', 'Tódor', 'Tóbiás',
                'Vencel', 'Viktor', 'Vilmos', 'Vince', 'Zalán', 'Zétény', 'Zoltán', 'Zsigmond', 'Zsolt',
               'Anna', 'Cecília', 'Erika', 'Hanna', 'Katalin', 'Mária', 'Nóra', 'Orsolya', 'Réka', 'Szilvia',
               'Tünde', 'Viktória', 'Dóra', 'Eszter', 'Flóra', 'Hajnalka', 'Izabella', 'Jázmin', 'Kamilla', 'Nikolett',
               'Panna', 'Rita', 'Sarolta', 'Zsófia', 'Ágota', 'Csilla', 'Lilla', 'Orsolya', 'Panna',
               'Szandra', 'Tamara', 'Ágnes', 'Júlia', 'Kincső', 'Babett', 'Barbara', 'Beáta', 'Bianka',
               'Blanka', 'Boglárka', 'Borbála', 'Boróka', 'Brigitta', 'Bernadett', 'Bettina', 'Berta', 'Betti',
               'Bianka', 'Cecília', 'Cintia', 'Csenge', 'Csilla', 'Detti', 'Diana', 'Dóra', 'Dalma', 'Daniella',
               'Debóra', 'Dolli', 'Dominika'
               ]

utca = ['Ady Endre utca', 'Akácfa utca', 'Alkotmány utca', 'Almássy tér', 'Andrássy út', 'Apáczai Csere János utca',
        'Aradi utca', 'Árpád fejedelem útja', 'Attila utca', 'Bajcsy-Zsilinszky út', 'Balassi Bálint utca',
        'Baross utca', 'Bartók Béla út', 'Batthyány tér', 'Bécsi utca', 'Belgrád rakpart', 'Bethlen Gábor tér',
        'Béke tér', 'Bem rakpart', 'Benczúr utca', 'Bérkocsis utca', 'Berzsenyi utca', 'Bihari utca', 'Bocskai utca',
        'Budaörsi út', 'Csarnok tér', 'Csévi utca', 'Csillaghegyi út', 'Csokonai utca', 'Csömöri utca', 'Dandár utca',
        'Darázs utca', 'Deák Ferenc utca', 'Dózsa György út', 'Egyetem tér', 'Erzsébet körút', 'Erzsébet tér',
        'Fadrusz utca', 'Fehérvári út', 'Kőrösi Csoma Sándor út', 'Ferenciek tere', 'Ferenc körút', 'Ferenc tér',
        'Feszty Árpád utca', 'Fő utca', 'Frankel Leó utca', 'Gát utca', 'Gönczy Pál utca', 'Gyömrői út',
        'Gyulai Pál utca', 'Hajós utca', 'Haller utca', 'Hársfa utca', 'Hattyú utca', 'Hegedűs Gyula utca',
        'Hegyalja út', 'Heltai Jenő utca', 'Hercegprímás utca', 'Hidegkúti út', 'Hűvösvölgyi út', 'Jókai utca',
        'József Attila utca', 'Kálmán Imre utca', 'Kálvin tér', 'Károly körút', 'Kassák Lajos utca',
        'Katona József utca', 'Káva utca', 'Kazinczy utca', 'Király utca',  'Klauzál tér', 'Klauzál utca',
        'Köztársaság tér', 'Kőbányai út', 'Közraktár utca', 'Klapka György út', 'Mártirok útja'
        'Krisztina körút', 'Kun utca', 'Váci út', 'Lajos utca', 'Lánchíd utca', 'Üllői út']

telepules = [
    'Abony', 'Ajka', 'Albertirsa', 'Apagy', 'Aszód', 'Baja', 'Balassagyarmat', 'Balatonalmádi',
    'Balatonfüred', 'Balmazújváros', 'Barcs', 'Bátaszék', 'Békéscsaba', 'Bélapátfalva', 'Berettyóújfalu',
    'Biatorbágy', 'Bicske', 'Bóly', 'Budakeszi', 'Budaörs', 'Budapest', 'Cegléd', 'Celldömölk',
    'Cigánd', 'Csongrád', 'Csorna', 'Csurgó', 'Dabas', 'Debrecen', 'Dég', 'Dombóvár', 'Dunaharaszti',
    'Dunaújváros', 'Dunakeszi', 'Dunapataj', 'Dunaszentmiklós', 'Edelény', 'Eger', 'Encs', 'Érd',
    'Érpatak', 'Esztár', 'Fehérgyarmat', 'Fót', 'Gárdony', 'Göd', 'Gödöllő', 'Gyál', 'Gyomaendrőd',
    'Gyömrő', 'Gyöngyös', 'Gyula', 'Hajdúböszörmény', 'Hajdúhadház', 'Hajdúnánás', 'Halásztelek',
    'Harkány', 'Hatvan', 'Hévíz', 'Hódmezővásárhely', 'Ibrány', 'Isaszeg', 'Jánossomorja', 'Jászberény',
    'Kaba', 'Kalocsa', 'Kapuvár', 'Karcag', 'Kápolna', 'Kaposvár', 'Kapuvár', 'Karcag', 'Kazincbarcika',
    'Kecel', 'Kecskemét', 'Kemecse', 'Keszthely', 'Kisbér', 'Kiskőrös', 'Kiskunfélegyháza',
    'Kiskunhalas', 'Kiskunlacháza', 'Kisújszállás', 'Komárom', 'Komló', 'Környe', 'Kőszeg',
    'Kunhegyes', 'Lábatlan', 'Lajosmizse', 'Lenti', 'Létavértes', 'Levél', 'Maglód', 'Magyarbánhegyes',
    'Makó', 'Marcali', 'Martfű', 'Mátészalka', 'Mátraháza', 'Mátraverebély', 'Mátyásdomb',
    'Medgyesegyháza', 'Mezőberény', 'Mezőcsát', 'Mezőkövesd', 'Mezőtúr',
    'Miskolc', 'Mohács', 'Monor', 'Monorierdő', 'Mór', 'Mosonmagyaróvár', 'Múcsony',
    'Nagyatád', 'Nagybajom', 'Nagybátony', 'Nagyecsed', 'Nagyhalász', 'Nagykálló', 'Nagykáta', 'Nagykőrös',
    'Nagykovácsi', 'Nagymányok', 'Nagymaros', 'Nagymező', 'Nagyrábé', 'Nagytarcsa', 'Nemesgulács',
    'Nemesvámos', 'Nógrád', 'Nyírbátor', 'Nyíregyháza', 'Ócsa', 'Orosháza', 'Oroszlány', 'Oroszi',
    'Őrbottyán', 'Paks', 'Pálháza', 'Pápa', 'Pásztó', 'Pécs', 'Pécsvárad', 'Pellérd', 'Pétfürdő',
    'Pilis', 'Pilisvörösvár', 'Polgár', 'Pomáz', 'Püspökladány', 'Putnok', 'Ráckeve', 'Rákoscsaba', 'Rátka',
    'Recsk', 'Répcelak', 'Rétság', 'Rigács', 'Romhány', 'Rozsály', 'Ságvár', 'Sajószentpéter', 'Salgótarján',
    'Sárbogárd', 'Sáregres', 'Sárisáp', 'Sárospatak', 'Sárvár', 'Sásd', 'Sátoraljaújhely', 'Sellye',
    'Siófok', 'Solt', 'Somlóvásárhely', 'Sopron', 'Sümeg', 'Szabadbattyán', 'Szabadszállás', 'Szajol',
    'Szakoly', 'Szakonyfalu', 'Szarvas', 'Szatmárcseke', 'Szatymaz', 'Szebény', 'Szekszárd', 'Szentendre',
    'Szentgotthárd', 'Szentkirályszabadja', 'Szentlőrinckáta', 'Szentmártonkáta', 'Szenttamás', 'Szigetbecse',
    'Szigethalom', 'Szigetszentmárton', 'Szigetszentmiklós', 'Szigetvár', 'Szilvásvárad', 'Szirák', 'Szolnok',
    'Szombathely', 'Tab', 'Táborfalva', 'Tápiószecső', 'Tapolca', 'Tárnok']

megye = ['Bács-Kiskun', 'Baranya', 'Békés', 'Borsod-Abaúj-Zemplén', 'Csongrád-Csanád', 'Fejér',
         'Győr-Moson-Sopron', 'Hajdú-Bihar', 'Heves', 'Jász-Nagykun-Szolnok', 'Komárom-Esztergom',
         'Nógrád', 'Pest', 'Somogy', 'Szabolcs-Szatmár-Bereg', 'Tolna', 'Vas', 'Veszprém', 'Zala']

folyo = ['Duna', 'Tisza', 'Dráva', 'Rába', 'Marcal', 'Szamos', 'Körös', 'Zagyva', 'Sajó', 'Ipoly',
         'Driszavica', 'Bodrog', 'Latorica', 'Zala', 'Hernád', 'Rábca', 'Lajta',
         'Kis-Duna', 'Fekete-Körös', 'Kis-Sajó', 'Torna', 'Kraszna', 'Mura', 'Séd', 'Kapos', 'Galga',
         'Cserna', 'Ivacs-patak', 'Bükkös-patak', 'Pilinka', 'Bodva', 'Hármas-Körös', 'Sajgó']

nap = ['hétfő', 'kedd', 'szerda', 'csütörtök', 'péntek', 'szombat', 'vasárnap']

honap = ['január', 'február', 'március', 'április', 'május', 'június', 'július',
         'augusztus', 'szeptember', 'október', 'november', 'december']

gyumolcs= ['alma', 'ananász',  'banán', 'barack', 'birs', 'cseresznye', 'datolya', 'dinnye', 'eper', 'füge',
            'gránátalma', 'kajszibarack', 'kivi', 'málna', 'meggy', 'narancs', 'őszibarack', 'ribizli',
            'sárgabarack', 'szeder', 'szilva', 'egres', 'vörösszőlő', 'szeder', 'körte', 'meggy', 'áfonya',
           'sárgadinnye', 'erdei szamóca', 'mangó']

zoldseg = ['articsóka', 'bab', 'borsó', 'brokkoli', 'burgonya', 'cékla', 'csicsóka', 'csiperkegomba', 'fokhagyma',
           'hagyma', 'karalábé', 'karfiol', 'káposzta', 'kelbimbó', 'kukorica', 'fejes sajáta', 'lilahagyma',
           'lilakáposzta', 'padlizsán', 'paprika', 'paszternák', 'retek', 'sárgarépa', 'spárga', 'spenót',
           'sütőtök', 'tök', 'uborka', 'zeller', 'sárgarépa', 'feketeretek','zeller', 'kínai kel', 'retek',
           'jégcsapretek', 'fokhagyma', 'újhagyma', 'szárzeller']

haszonallat = [ 'tehén', 'juh', 'kecske', 'disznó', 'tyúk', 'kacsa', 'liba', 'pulyka', 'strucc', 'ló', 'szamár', 'bivaly',
                 'jak', 'csirke', 'nyúl', 'szarvasmarha', 'szürkemarha', 'sertés', 'malac', 'gyöngytyúk', 'birka']

vad = ['medve', 'farkas', 'róka', 'borz', 'őz', 'szarvas','nyest', 'vaddisznó','muflon','vidra',
            'gímszarvas', 'molnárgörény','vadmacska']

hal = ['keszeg', 'ponty', 'csuka', 'harcsa', 'süllő', 'kárász', 'angolna', 'márna', 'fogasponty', 'sügér', 'amur',
         'menyhal', 'domolykó', 'keszeg', 'garda', 'paduc', 'compó', 'bodorka', 'nyúldomolykó']

madar = ['feketerigó', 'fülemüle', 'csalogány', 'kékvércse', 'széncinege', 'szajkó', 'szürkebegy', 'búbosbanka',
         'zöldike', 'sármány', 'fácán', 'kakukk', 'bölömbika', 'örvényi sas', 'szirti sas', 'parlagi sas',
         'réti keselyű', 'héja', 'pávaszemes fecske', 'gyurgyalag', 'gólya', 'kócsag', 'hattyú', 'vadkacsa', 'vadlúd',
         'szárcsa', 'rigó', 'szajkó']

bolygo =['Merkúr', 'Vénusz', 'Föld', 'Mars', 'Jupiter','Szaturnusz', 'Uránusz', 'Neptunusz']


leves = ["Gulyásleves", "Halászlé", "Hideg meggyleves", "Zöldborsóleves", "Jókai bableves", "Csontleves",
           "Marhahúsleves", "Zellerkrémleves", "Sárgaborsóleves", "Babgulyásleves", "Karalábéleves", "Zöldségleves",
           "Kukoricaleves", "Karfiolleves", "Hideg gyümölcsleves", "Korhelyleves", "Tyúkhúsleves",
           "Pirított tarhonyaleves", "Gombaleves", "Lencseleves", "Gulyáskrémleves", "Csülökleves", "Paradicsomleves",
           "Borleves", "Tárkonyos raguleves", "Zöldbableves", "Kapros-joghurtos leves", "Paradicsomleves betűtésztával",
           "Sajtos-tejfölös leves", "Burgonyaleves", "Csirkeleves", "Krumplileves",  "Tavaszi zöldségleves",
           "Karfiol krémleves", "Tojásleves", "Tárkonyos csirkeraguleves", "Káposztaleves", "Húsos zöldborsóleves",
           "Sárgadinnyeleves", "Tavaszi zöldségleves tarhonyával", "Hagymaleves",  "Húsleves gazdagon",
           "Gesztenyekrémleves", "Jérceleves", "Kolbászos bableves", "Uborkaleves", "Tejszínes karfiolleves",
           "Tarkabableves", "Hideg szilvaleves", "Fokhagymaleves", "Májgombócleves", "Brokkolileves",
           "Savanyú káposztaleves", "Erőleves", "Tejfölös gombaleves",  "Húsos káposztaleves", "Zöldspárga krémleves",
           "Sóska krémleves", "Burgonyapüréleves", "Laskaleves",  "Paradicsomleves húsgombóccal", "Csirkemájleves",
           "Ribizlileves", "Cukkinikrémleves", "Fokhagymás zöldbableves", "Zöldségleves tojással"]

foetel= ['Vadörkölt', 'Sült csirke',
         'Sertésszelet', 'Rántott hús', 'Paprikás csirke', 'Sült kolbász', 'Rántott sajt', 'Rántott karfiol',
         'Kacsacomb rántva', 'Kakaspörkölt',  'Sült hal',  'Gombapaprikás',
         'Marhapörkölt', 'Pacalpörkölt', 'Roston sült csirke',
         'Rántott gomba', 'Rántott karaj', 'Rántott csirkemell', 'Halpaprikás', 'Libamáj',
         'Sült sertés', 'Halpaprikás', 'Csülök Pékné módra', 'Borjúpörkölt ',
         'Párizsi csirkemell', 'Rántott karaj', 'Kacsapörkölt', 'Csirkepaprikás',  'Rántott csirkeszárny', 'Pacalpörkölt',
         'Rántott jércemell', 'Sertéspörkölt','Mátrai borzaska',
         'Grillezett csirkecomb', 'Lecsós csirke', 'Rántott gomba ', 'Rántott ponty', 'Lazacsteak', 'Roston sült hal',
         'Rántott camembert', 'Sült kacsacomb', 'Sült libacomb', 'Sült pulykamell', 'Sült tarja', 'Báránytokány',
         'Szűzérmék',  'Cordon bleu', 'Sült Kacsamáj',
         'Lecsós tarja', 'Stefánia vagdalt']

koret = ['Párolt rizs', 'Hagymás tört burgonya', 'Burgonyapüré', 'Párolt zöldségek', 'Hasábburgonya',
           'Grillezett zöldségek', 'Köleskása', 'Galuska', 'Zöldségköret', 'Kukoricás rizs', 'Sárgarépa püré',
            'Tarhonya',  'Burgonyakrokett', 'Kuszkusz', 'Brokkolipüré', 'Párolt sárgarépa',
           'Tarhonya',  'Zöldborsós rizs', 'Gombás rizs', 'Gersli',  'Sült édesburgonya hasáb',
           'Édesburgonya püré',  'Hercegnő burgonya', 'Csónak burgonya', 'Tepsis sült burgonya']

egytal = ['Rakott krumpli', 'Töltött káposzta', 'Lecsó','Töltött paprika','Lencsefőzelék sültkolbásszal','Hortobágyi húsos palacsinta',
          'Sztrapacska szalonna pörccel','Burgonyás tészta','Csirkés rizottó','Rakott kelkáposzta csőben sütve',
           'Rakott zöldbab', 'Disznótoros káposzta friss kenyérrel', 'Bácskai rizseshús', 'Brassói aprópecsenye','Tarhonyás hús',
          'Székelykáposzta kenyérrel','Paradicsomos töltött káposzta','Rakott cukkini', 'Pásztortarhonya','Húsos-szaftos tészta',
          'Lecsó Mezőcsáti módra', 'Sonkás-paradicsomos tészta', 'Sajtos-sonkás rakott tészta', 'Kolozsvári rakott káposzta',
          'Sonkás tészta csőben sütve','Túrós csusza','Kapros-túrós csusza', 'Székelykáposzta','Paprikás krumpli', 'Rakott padlizsán' ]

desszert = [
    'Almás pite', 'Aranygaluska','Bejgli','Bodri torta','Boszorkányszigeti torta','Budapest roló', 'Császármorzsa',
    'Csokoládé torta','Dobostorta','Diótorta', 'Esterházy torta','Fekete-erdő torta','Flódni','Gesztenyepüré torta',
    'János vitéz tortája', 'Joghurt torta', 'Kakaós-meggyes pite', 'Képviselőfánk', 'Két színű torta',
    'Kókuszos szelet', 'Krémes', 'Linzer', 'Mákos guba', 'Mákos kalács', 'Napóleon torta', 'Orosz krémtorta',
    'Francia krémes', 'Puncsgolyó','Rakott palacsinta','Rákóczi túrós','Rigó Jancsi', 'Somlói galuska',
    'Tiramisu','Répatorta']

bor = ['Tokaji Furmint', 'Villányi Franc', 'Eger Bikavér', 'Szekszárdi Bikavér', 'Balatonboglári Kékfrankos',
       'Badacsonyi Olaszrizling', 'Villányi Portugieser', 'Villányi Cabernet Franc', 'Egri Kékfrankos',
       'Villányi Merlot', 'Etyeki Chardonnay', 'Somlói Juhfark', 'Tokaji Aszú', 'Mátrai Irsai Olivér',
       'Villányi Cabernet Sauvignon', 'Balatonfüredi Szürkebarát', 'Soproni Kékfrankos', 'Szekszárdi Kadarka',
       'Szekszárdi Merlot', 'Balatonlellei Olaszrizling', 'Badacsonyi Kéknyelű', 'Villányi Syrah',
       'Somlói Furmint', 'Tokaji Szamorodni', 'Villányi Cuvée', 'Villányi Pinot Noir', 'Badacsonyi Kékfrankos',
       'Mátrai Pinot Noir', 'Tokaji Hárslevelű', 'Villányi Kékfrankos', 'Somlói Traminer',
       'Badacsonyi Muscat Ottonel', 'Villányi Kadarka', 'Mátrai Cabernet Sauvignon', 'Soproni Pinot Noir',
       'Balatonfüredi Olaszrizling', 'Badacsonyi Szürkebarát', 'Tokaji Szamorodni Édes', 'Egri Leányka',
       'Szekszárdi Cuvée', 'Villányi Kéknyelű', 'Egri Merlot', 'Somlói Olaszrizling',
       'Badacsonyi Rizlingszilváni', 'Villányi Portugieser Rosé', 'Balatonboglári Zenit',
       'Balatonlellei Riesling', 'Tokaji Szamorodni Száraz', 'Soproni Rosé']

udito = ['Narancslé', 'Almalé', 'Tonik', 'Ásványvíz', 'Gyümölcslé', 'Szőlőlé',
        'Bodza szörp', 'Cseresznyeszörp', 'Málnaszörp', 'Eper szörp',  'Zöld teás üdítő',
        'Narancs ízű ásványvíz','Coca Cola', 'Fanta', 'Sprite', 'Jeges tea', 'Gyömbér',
        'Bambi', 'Róna', 'Márka','Traubisoda','Olympos','Málna-gyöngye','Meggy-gyöngye',
        'Sió gyümölcs nektár','Limonádé']



kiraly = {'Árpád': (895, 907), 'Zoltán': (907, 947), 'Fajsz': (947, 955), 'Taksony': (955, 972), 'Géza': (972, 997),
    'I.István': (997, 1038),'I. Péter': (1038, 1041), 'Sámuel': (1041, 1044), 'Péter-2': (1044, 1045), 'I.András': (1041, 1060),
    'I. Béla': (1060, 1063), 'Salamon': (1063, 1074), 'I. Géza': (1074, 1077), 'I. László': (1077, 1095),
    'Kálmán': (1095, 1116),'II. István': (1116, 1131), 'II. Béla': (1131, 1141), 'II. Géza': (1141,1162),
    'III. István': (1162, 1172), 'III. Béla': (1172, 1196), 'Imre':(1196, 1204), 'III. László': (1204, 1205),
    'II. András': (1205, 1235),'IV. Béla': (1235, 1270), 'V. István': (1270, 1272), 'IV. László': (1272, 1290),
    'III. András': (1290, 1301), 'Vencel': (1301, 1305), 'Ottó': (1305, 1307), 'I. Károly': (1308, 1342),
    'I.Lajos': (1342, 1382), 'Mária': (1382, 1385), 'II. Károly': (1385, 1386), 'Mária-2':(1386, 1395),
    'Zsigmond' : (1387, 1437), 'Albert': (1437, 1439), 'V. László': (1440, 1457), 'I. Ulászló': (1440, 1444),
    'I. Mátyás': (1458, 1490), 'II. Ulászló': (1490, 1516), 'II. Lajos': (1516, 1526), 'I.János': (1526, 1540),
    'II. János' : (1540, 1571), 'I. Ferdinánd': (1526, 1564), 'Miksa': (1564, 1576), 'Rudolf': (1576, 1608),
    'II. Mátyás': (1608, 1619), 'II. Ferdinánd': (1618, 1637), 'III. Ferdinánd': (1637,1657), 'IV. Ferdinánd': (1647,1654),
    'I. Lipót' : (1657, 1705),  'I. József': (1705,1711), 'III. Károly': (1711,1740), 'Mária Terézia': (1740, 1780),
    'II. József':(1780, 1790), 'II. Lipót': (1790, 1792), 'I. Ferenc': (1790, 1835), 'V. Ferdinánd' : (1835,1848),
    'I. Ferenc József' : (1848,1916), 'IV. Károly':(1916,1918) }

megye_szekhely= {'Bács-Kiskun': 'Kecskemét','Baranya': 'Pécs', 'Békés': 'Békéscsaba','Borsod-Abaúj-Zemplén': 'Miskolc',
    'Csongrád-Csanád': 'Szeged','Fejér': 'Székesfehérvár', 'Győr-Moson-Sopron': 'Győr','Hajdú-Bihar': 'Debrecen',
    'Heves': 'Eger','Jász-Nagykun-Szolnok': 'Szolnok', 'Komárom-Esztergom': 'Tatabánya', 'Nógrád': 'Salgótarján',
    'Pest': 'Budapest', 'Somogy': 'Kaposvár', 'Szabolcs-Szatmár-Bereg': 'Nyíregyháza', 'Tolna': 'Szekszárd',
    'Vas': 'Szombathely', 'Veszprém': 'Veszprém', 'Zala': 'Zalaegerszeg' }

jaras= {
    'Bácsalmási járás': ['Bácsalmás', 'Bács-Kiskun'],'Bajai járás': ['Baja', 'Bács-Kiskun'],
    'Jánoshalmi járás': ['Jánoshalma', 'Bács-Kiskun'],'Kalocsai járás': ['Kalocsa', 'Bács -Kiskun'],
    'Kecskeméti járás': ['Kecskemét', 'Bács-Kiskun'], 'Kiskőrösi járás': ['Kiskőrös', 'Bács-Kiskun'],
    'Kiskunfélegyházi járás': ['Kiskunfélegyháza', 'Bács-Kiskun'], 'Kiskunhalasi járás': ['Kiskunhalas', 'Bács-Kiskun'],
    'Kunszentmiklósi járás': ['Kunszentmiklós', 'Bács-Kiskun'], 'Tiszakécskei járás': ['Tiszakécske', 'Bács-Kiskun'],
    'Kiskunmajsai járás' :['Kiskunmajsa', 'Bács-Kiskun'],
    'Bólyi járás': ['Bóly', 'Baranya'], 'Hegyháti járás': ['Sásd', 'Baranya'],
    'Komlói járás': ['Komló', 'Baranya'],'Mohácsi járás': ['Mohács', 'Baranya'],
    'Pécsi járás': ['Pécs', 'Baranya'], 'Pécsváradi járás': ['Pécsvárad', 'Baranya'],
    'Sellyei járás': ['Sellye', 'Baranya'], 'Szentlőrinci járás': ['Szentlőrinc', 'Baranya'],
    'Siklósi járás': ['Siklós', 'Baranya'], 'Szigetvári járás': ['Szigetvár', 'Baranya'],
    'Békési járás':['Békés', 'Békés'],'Gyulai járás': ['Gyula', 'Békés'],
    'Mezőkovácsházi járás': ['Mezőkovácsháza', 'Békés'],'Orosházi járás': ['Orosháza', 'Békés'],
    'Sarkadi járás': ['Sarkad', 'Békés'], 'Szeghalmi járás': ['Szeghalom', 'Békés'],
    'Békéscsabai járás':['Békéscsaba', 'Békés'], 'Gyomaendrődi járás':['Gyomaendrőd', 'Békés'],
    'Szarvasi járás':['Szarvas', 'Békés'],
    'Cigándi járás': ['Cigánd', 'Borsod-Abaúj-Zemplén'], 'Edelényi járás': ['Edelény', 'Borsod-Abaúj-Zemplén'],
    'Encsi járás': ['Encs', 'Borsod-Abaúj-Zemplén'], 'Gönci járás': ['Gönc', 'Borsod-Abaúj-Zemplén'],
    'Kazincbarcikai járás': ['Kazincbarcika', 'Borsod-Abaúj-Zemplén'], 'Mezőcsáti járás': ['Mezőcsát', 'Borsod-Abaúj-Zemplén'],
    'Mezőkövesdi járás': ['Mezőkövesd', 'Borsod-Abaúj-Zemplén'],  'Miskolci járás': ['Miskolc', 'Borsod-Abaúj-Zemplén'],
    'Ózdi járás': ['Ózd', 'Borsod-Abaúj-Zemplén'],  'Putnoki járás': ['Putnok', 'Borsod-Abaúj-Zemplén'],
    'Sárospataki járás': ['Sárospatak', 'Borsod-Abaúj-Zemplén'], 'Sátoraljaújhelyi járás': ['Sátoraljaújhely', 'Borsod-Abaúj-Zemplén'],
    'Szerencsi járás': ['Szerencs', 'Borsod-Abaúj-Zemplén'],  'Szikszói járás': ['Szikszó', 'Borsod-Abaúj-Zemplén'],
    'Tiszaújvárosi járás': ['Tiszaújváros', 'Borsod-Abaúj-Zemplén'],  'Tokaji járás': ['Tokaj', 'Borsod-Abaúj-Zemplén'],
    'Csongrádi járás': ['Csongrád', 'Csongrád-Csanád'],'Hódmezővásárhelyi járás': ['Hódmezővásárhely', 'Csongrád-Csanád'],
    'Kisteleki járás': ['Kistelek', 'Csongrád-Csanád'], 'Makói járás': ['Makó', 'Csongrád-Csanád'],
    'Mórahalmi járás': ['Mórahalom', 'Csongrád-Csanád'],'Szegedi járás': ['Szeged', 'Csongrád-Csanád'],
    'Szentesi járás': ['Szentes', 'Csongrád-Csanád'],
    'Bicskei járás': ['Bicske', 'Fejér'], 'Dunaújvárosi járás': ['Dunaújváros', 'Fejér'],
    'Enyingi járás': ['Enying', 'Fejér'],'Gárdonyi járás': ['Gárdony', 'Fejér'],
    'Martonvásári járás': ['Martonvásár', 'Fejér'],'Móri járás': ['Mór', 'Fejér'],
    'Sárbogárdi járás': ['Sárbogárd', 'Fejér'], 'Székesfehérvári járás': ['Székesfehérvár', 'Fejér'],
    'Csornai járás': ['Csorna', 'Győr-Moson-Sopron'], 'Győri járás': ['Győr', 'Győr-Moson-Sopron'],
    'Kapuvári járás': ['Kapuvár', 'Győr-Moson-Sopron'], 'Mosonmagyaróvári járás': ['Mosonmagyaróvár', 'Győr-Moson-Sopron'],
    'Pannonhalmi járás': ['Pannonhalma', 'Győr-Moson-Sopron'], 'Soproni járás': ['Sopron', 'Győr-Moson-Sopron'],
    'Téti járás': ['Tét', 'Győr-Moson-Sopron'],
    'Balmazújvárosi járás': ['Balmazújváros', 'Hajdú-Bihar'],'Berettyóújfalui járás': ['Berettyóújfalu', 'Hajdú-Bihar'],
    'Debreceni járás': ['Debrecen', 'Hajdú-Bihar'],'Derecskei járás': ['Derecske', 'Hajdú-Bihar'],
    'Hajdúböszörményi járás': ['Hajdúböszörmény', 'Hajdú-Bihar'],'Hajdúhadházi járás': ['Hajdúhadház', 'Hajdú-Bihar'],
    'Hajdúnánási járás': ['Hajdúnánás', 'Hajdú-Bihar'],'Hajdúszoboszlói járás': ['Hajdúszoboszló', 'Hajdú-Bihar'],
    'Nyíradonyi járás': ['Nyíradony', 'Hajdú-Bihar'],'Püspökladányi járás': ['Püspökladány', 'Hajdú-Bihar'],
    'Bélapátfalvai járás': ['Bélapátfalva', 'Heves'], 'Egri járás': ['Eger', 'Heves'],
    'Füzesabonyi járás': ['Füzesabony', 'Heves'], 'Gyöngyösi járás': ['Gyöngyös', 'Heves'],
    'Hatvani járás': ['Hatvan', 'Heves'],'Hevesi járás': ['Heves', 'Heves'],
    'Pétervásárai járás': ['Pétervására', 'Heves'],
    'Jászapáti járás': ['Jászapáti', 'Jász-Nagykun-Szolnok'],'Jászberényi járás': ['Jászberény', 'Jász-Nagykun-Szolnok'],
    'Karcagi járás': ['Karcag', 'Jász-Nagykun-Szolnok'],'Kunhegyesi járás': ['Kunhegyes', 'Jász-Nagykun-Szolnok'],
    'Kunszentmártoni járás': ['Kunszentmárton', 'Jász-Nagykun-Szolnok'],
    'Mezőtúri járás': ['Mezőtúr', 'Jász-Nagykun-Szolnok'],
    'Szolnoki járás': ['Szolnok', 'Jász-Nagykun-Szolnok'],
    'Tiszafüredi járás': ['Tiszafüred', 'Jász-Nagykun-Szolnok'],
    'Törökszentmiklósi járás': ['Törökszentmiklós', 'Jász-Nagykun-Szolnok'],
    'Esztergomi járás': ['Esztergom', 'Komárom-Esztergom'],'Kisbéri járás': ['Kisbér', 'Komárom-Esztergom'],
    'Komáromi járás': ['Komárom', 'Komárom-Esztergom'], 'Oroszlányi járás': ['Oroszlány', 'Komárom-Esztergom'],
    'Tatabányai járás': ['Tatabánya', 'Komárom-Esztergom'],'Tatai járás': ['Tata', 'Komárom-Esztergom'],
    'Balassagyarmati járás': ['Balassagyarmat', 'Nógrád'], 'Bátonyterenyei járás': ['Bátonyterenye', 'Nógrád'],
    'Pásztói járás': ['Pásztó', 'Nógrád'], 'Rétsági járás': ['Rétság', 'Nógrád'],
    'Salgótarjáni járás': ['Salgótarján', 'Nógrád'], 'Szécsényi járás': ['Szécsény', 'Nógrád'],
    'Aszódi járás': ['Aszód', 'Pest'],'Budakeszi járás': ['Budakeszi', 'Pest'],
    'Ceglédi járás': ['Cegléd', 'Pest'],'Dabasi járás': ['Dabas', 'Pest'],
    'Dunakeszi járás': ['Dunakeszi', 'Pest'],'Érdi járás': ['Érd', 'Pest'],
    'Gödöllői járás': ['Gödöllő', 'Pest'], 'Gyáli járás': ['Gyál', 'Pest'],
    'Monori járás': ['Monor', 'Pest'],'Nagykátai járás': ['Nagykáta', 'Pest'],
    'Nagykőrösi járás': ['Nagykőrös', 'Pest'],'Pilisvörösvári járás': ['Pilisvörösvár', 'Pest'],
    'Ráckevei járás': ['Ráckeve', 'Pest'], 'Szentendrei járás': ['Szentendre', 'Pest'],
    'Szigetszentmiklósi járás': ['Szigetszentmiklós', 'Pest'],'Szobi járás': ['Szob', 'Pest'],
    'Váci járás': ['Vác', 'Pest'],'Vecsési járás': ['Vecsés', 'Pest'],
    'Barcsi járás': ['Barcs', 'Somogy'],  'Csurgói járás': ['Csurgó', 'Somogy'],
    'Fonyódi járás': ['Fonyód', 'Somogy'], 'Kaposvári járás': ['Kaposvár', 'Somogy'],
    'Marcali járás': ['Marcali', 'Somogy'], 'Nagyatádi járás': ['Nagyatád', 'Somogy'],
    'Siófoki járás': ['Siófok', 'Somogy'], 'Tabi járás': ['Tab', 'Somogy'],
    'Baktalórántházai járás': ['Baktalórántháza', 'Szabolcs-Szatmár-Bereg'],'Csengeri járás': ['Csenger', 'Szabolcs-Szatmár-Bereg'],
    'Fehérgyarmati járás': ['Fehérgyarmat', 'Szabolcs-Szatmár-Bereg'], 'Ibrányi járás': ['Ibrány', 'Szabolcs-Szatmár-Bereg'],
    'Kemecsei járás': ['Kemecse', 'Szabolcs-Szatmár-Bereg'],'Kisvárdai járás': ['Kisvárda', 'Szabolcs-Szatmár-Bereg'],
    'Mátészalkai járás': ['Mátészalka', 'Szabolcs-Szatmár-Bereg'], 'Nagykállói járás': ['Nagykálló', 'Szabolcs-Szatmár-Bereg'],
    'Nyírbátori járás': ['Nyírbátor', 'Szabolcs-Szatmár-Bereg'], 'Nyíregyházi járás': ['Nyíregyháza', 'Szabolcs-Szatmár-Bereg'],
    'Tiszavasvári járás': ['Tiszavasvári', 'Szabolcs-Szatmár-Bereg'],'Vásárosnaményi járás': ['Vásárosnamény', 'Szabolcs-Szatmár-Bereg'],
    'Záhonyi járás': ['Záhony', 'Szabolcs-Szatmár-Bereg'],
    'Bonyhádi járás': ['Bonyhád', 'Tolna'], 'Dombóvári járás': ['Dombóvár', 'Tolna'],
    'Paksi járás': ['Paks', 'Tolna'], 'Szekszárdi járás': ['Szekszárd', 'Tolna'],
    'Tamási járás': ['Tamási', 'Tolna'], 'Tolnai járás': ['Tolna', 'Tolna'],
    'Celldömölki járás': ['Celldömölk', 'Vas'],'Körmendi járás': ['Körmend', 'Vas'], 'Kőszegi járás': ['Kőszeg', 'Vas'],
    'Sárvári járás': ['Sárvár', 'Vas'],'Szentgotthárdi járás': ['Szentgotthárd', 'Vas'],
    'Szombathelyi járás': ['Szombathely', 'Vas'],   'Vasvári járás': ['Vasvár', 'Vas'],
    'Ajkai járás': ['Ajka', 'Veszprém'], 'Balatonalmádi járás': ['Balatonalmádi', 'Veszprém'],
    'Balatonfüredi járás': ['Balatonfüred', 'Veszprém'], 'Devecseri járás': ['Devecser', 'Veszprém'],
    'Pápai járás': ['Pápa', 'Veszprém'], 'Sümegi járás': ['Sümeg', 'Veszprém'],'Tapolcai járás': ['Tapolca', 'Veszprém'],
    'Várpalotai járás': ['Várpalota', 'Veszprém'], 'Veszprémi járás': ['Veszprém', 'Veszprém'], 'Zirci járás': ['Zirc', 'Veszprém'],
    'Keszthelyi járás': ['Keszthely', 'Zala'],'Lenti járás': ['Lenti', 'Zala'],'Letenyei járás': ['Letenye', 'Zala'],
    'Nagykanizsai járás': ['Nagykanizsa', 'Zala'],'Zalaegerszegi járás': ['Zalaegerszeg', 'Zala'],
    'Zalaszentgróti járás': ['Zalaszentgrót', 'Zala'] }

villamos = {
            "BKK1": {"viszonylat":1, "indulas": "Kelenföld vasútállomás", "erkezes": "Bécsi út/Vörösvári út","menetido": 50,"varos": "Budapest" },
            "BKK2":{"viszonylat": 2, "indulas": "Jászai Mari tér", "erkezes" : "Közvágóhíd", "menetido" : 22 ,"varos": "Budapest" },
            "BKK3":{"viszonylat": 3, "indulas": "Mexikói út metróállomás", "erkezes" : "Gubacsi út/ Határ út", "menetido" : 47,"varos": "Budapest" },
            "BKK4":{ "viszonylat": 4,"indulas": "Széll Kálmán tér metróállomás", "erkezes" : "Újbuda központ metróállomás", "menetido": 30,"varos": "Budapest" },
            "BKK6":{ "viszonylat": 6,"indulas": "Széll Kálmán tér metróállomás", "erkezes" : "Móricz Zsigmond körtér metróállomás", "menetido" : 30 ,"varos": "Budapest"},
            "BKK12":{"viszonylat": 12, "indulas": "Angyalföld kocsiszín", "erkezes" : "Rákospalota Kossuth utca", "menetido" : 14,"varos": "Budapest"},
            "BKK14":{"viszonylat": 14,"indulas": "Lehel tér metróállomás", "erkezes" : "Káposztásmegye, Megyeri út", "menetido" : 33 ,"varos": "Budapest"},
            "BKK17":{"viszonylat": 17,"indulas": "Savoya park", "erkezes" : "Bécsi út/ Vörösvári út", "menetido" : 52,"varos": "Budapest" },
            "BKK19":{"viszonylat": 19, "indulas": "Kelenföld vasútállomás", "erkezes" : "Bécsi út / Vörösvári út", "menetido" : 40,"varos": "Budapest"},
            "BKK23":{"viszonylat": 23, "indulas": "Jászai Mari tér", "erkezes" : "Keleti pályaudvar metróállomás", "menetido": 35,"varos": "Budapest"},
            "BKK24":{"viszonylat": 24,"indulas": "Keleti pályudvar metróállomás", "erkezes" : "Közvágóhíd HÉV állomás", "menetido": 18,"varos": "Budapest"},
            "BKK28":{"viszonylat": 28, "indulas": "Blaha Lujza tér metróállomás", "erkezes" : "Izraelita temető", "menetido": 38,"varos": "Budapest"},
            "BKK37":{"viszonylat": 37,"indulas": "Blaha Lujza tér metróállomás", "erkezes" : "Új köztemető (Kozma utca)", "menetido": 31,"varos": "Budapest"},
            "BKK41":{"viszonylat": 41, "indulas": "Kamaraerdei ifjúsági park", "erkezes" : "Bécsi út / Vörösvári út", "menetido": 62,"varos": "Budapest"},
            "BKK42":{"viszonylat": 42, "indulas": "Határ út metróállomás", "erkezes" : "Kispest Tulipán utca", "menetido": 8,"varos": "Budapest"},
            "BKK47":{"viszonylat": 47, "indulas": "Deák Ferenc tér metróállomás", "erkezes" : "Városház tér", "menetido": 31,"varos": "Budapest"},
            "BKK48":{"viszonylat": 48, "indulas": "Savoya park", "erkezes" : "Deák Ferenc tér metróállomás", "menetido": 28,"varos": "Budapest"},
            "BKK49":{"viszonylat": 49, "indulas": "Kelenföld vasútállomás", "erkezes" : "Deák Ferenc tér metróállomás", "menetido": 20,"varos": "Budapest"},
            "BKK50":{ "viszonylat": 50,"indulas": "Határ út", "erkezes" : "Pestszentlőrinc ,Béke tér", "menetido": 25,"varos": "Budapest"},
            "BKK51":{ "viszonylat": 51,"indulas": "Nagysándor József utca", "erkezes" : "Ferenc körút/Mester utca", "menetido": 28,"varos": "Budapest"},
            "BKK52":{ "viszonylat": 52,"indulas": "Határ út metróállomás", "erkezes" : "Pesterzsébet, Pacsirtatelep", "menetido": 25,"varos": "Budapest"},
            "BKK56":{"viszonylat": 56, "indulas": "Hűvösvölgy", "erkezes" : "Városház tér", "menetido": 56,"varos": "Budapest"},
            "BKK59":{"viszonylat": 59,"indulas": "Márton Áron tér", "erkezes" : "Szent János kórház", "menetido": 19,"varos": "Budapest"},
            "BKK60":{"viszonylat": 60,"indulas": "Városmajor", "erkezes" : "Széchenyi-hegy, Gyermekvasút", "menetido": 14,"varos": "Budapest"},
            "BKK61": {"viszonylat": 61, "indulas": "Móricz Zsigmond körtér", "erkezes" : "Hűvösvölgy", "menetido": 35,"varos": "Budapest"},
            "BKK62":{"viszonylat": 62, "indulas": "Blaha Lujza tér metróállomás", "erkezes" : "Rákospalota, MÁV-telep", "menetido": 47,"varos": "Budapest"},
            "BKK69":{"viszonylat": 69, "indulas": "Újpalota, Erdőkerülő utca", "erkezes" : "Mexikói út metróállomás", "menetido": 56,"varos": "Budapest"},
            "DKV1": {"viszonylat": 1, "indulas": "Nagyállomás", "erkezes": "Nagyállomás", "menetido": 38, "varos": "Debrecen"},
            "DKV2": {"viszonylat": 2, "indulas": "Nagyállomás", "erkezes": "Nagyállomás", "menetido": 44, "varos": "Debrecen"},
            "MVK1": {"viszonylat": 1, "indulas": "Tiszai pályaudvar", "erkezes": "Felső-Majláth", "menetido": 33,"varos": "Miskolc"},
            "MVK2": {"viszonylat": 2, "indulas": "Tiszai pályaudvar", "erkezes": "Újgyőri főtér", "menetido": 26,"varos": "Miskolc"},
            "SZKT1": {"viszonylat": 1, "indulas": "Szeged plaza", "erkezes": "Szeged vasútállomás", "menetido": 33, "varos": "Szeged"},
            "SZKT2": {"viszonylat": 2, "indulas": "Európa liget", "erkezes": "Szeged vasútállomás", "menetido": 33, "varos": "Szeged"},
}

orszag= {
    "Albánia": "Tirana","Andorra": "Andorra város", "Ausztria": "Bécs", "Belgium": "Brüsszel",
    "Bosznia és Hercegovina": "Szarajevó",  "Bulgária": "Szófia",  "Ciprus": "Nicosia",
    "Csehország": "Prága",  "Dánia": "Koppenhága", "Észtország": "Tallinn", "Finnország": "Helsinki",
    "Franciaország": "Párizs", "Görögország": "Athén", "Horvátország": "Zágráb", "Izland": "Reykjavík",
    "Írország": "Dublin", "Koszovó": "Pristina", "Lengyelország": "Varsó", "Lettország": "Riga",
    "Liechtenstein": "Vaduz",  "Litvánia": "Vilnius",  "Luxemburg": "Luxemburg",
    "Magyarország": "Budapest",  "Málta": "Valletta",  "Moldova": "Kisinyov",  "Monaco": "Monaco",
    "Montenegró": "Podgorica", "Németország": "Berlin", "Norvégia": "Oslo", "Olaszország": "Róma",
    "Portugália": "Lisszabon", "Románia": "Bukarest", "San Marino": "San Marino",
    "Spanyolország": "Madrid", "Svájc": "Bern",  "Svédország": "Stockholm",  "Szlovákia": "Pozsony",
    "Szlovénia": "Ljubljana", "Törökország": "Ankara", "Ukrajna": "Kijev", "Vatikán": "Vatikánváros"
}

def szotarbol_veletlen_kulcs(szotar, n):
    """
        szotar (dict): A szótár, amelyből véletlenszerűen választunk kulcsokat.
        n (int): A választandó kulcsok száma.
    """
    kulcsok = list(szotar.keys())
    veletlen_kulcsok = []
    for i in range(n):
        kulcs_index = hash(str(i)) % len(kulcsok)
        veletlen_kulcs = kulcsok[kulcs_index]
        veletlen_kulcsok.append(veletlen_kulcs)
    return veletlen_kulcsok

def tordel(lst, n=None):  # lst = kiírandó lista, n = hany kerüljön  egy sorba
    if n is None:
        n = 10
    for i in range(0, len(lst), n):
        row = lst[i:i+n]
        print(", ".join(map(str, row)), end=", ")
        print()

def ftordel(lst, n=None, indent=None):
    if n is None:
        n = 10
    if indent is None:
        indent = ''
    tordelt_sorok = []
    for i in range(0, len(lst), n):
        row = lst[i:i+n]
        tordelt_sorok.append(f"{indent}{', '.join(map(str, row))}")
    return "\n".join(tordelt_sorok)

ABECEDARAK = 'aábcdeéfghiíjklmnoóöőpqrstuúüűvwxyz'
def abc(lista):
    return sorted(lista, key=lambda s: [ABECEDARAK.find(c) for c in s.lower()])

def fel_kerekit(szam):
    if szam % 1 == 0:
        return int(szam)
    else:
        return int(szam) + 1

def le_kerekit(szam):
    return int(szam // 1)



from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="magyar",
    version="3.0.4",
    author="Nagy Béla",
    author_email="nagy.belabudapest@gmail.com",
    description="Hungarian lists of names,animals,foods, fruits, rivers ..",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/kobanya/nevek",
    py_modules=["magyar"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
